#!/usr/bin/env python

"""Setup script for the CSplitter module distribution."""

import os, sys
from distutils.core import setup
from distutils.extension import Extension

if sys.platform == "linux-i386": # Red Hat
    include_dirs=['/usr/local/db/BerkeleyDB/include','/usr/local/tabe/include']
    library_dirs=['/usr/local/db/BerkeleyDB/lib','/usr/local/tabe/lib']
    libraries = ["tabe", "db"]
    runtime_library_dirs = []
    extra_objects = ['/usr/local/db/BerkeleyDB/lib/libdb.a']
elif sys.platform in ("freebsd4", "openbsd2"): 
    include_dirs=['/usr/home/tcchou/works/BerkeleyDB/include','/usr/home/tcchou/works/tabe/include']
    library_dirs=['/usr/home/tcchou/works/BerkeleyDB/lib','/usr/home/tcchou/works/tabe/lib']
    libraries = ["tabe", "db"]
    runtime_library_dirs = []
    extra_objects = []
elif sys.platform == "win32":
    include_dirs = [r'd:\tcchou\works\tabe\include']
    library_dirs = [r'd:\tcchou\works\tabe\lib']
    libraries = ['libdb','libtabe', 'msvcrt', 'libcmt',
                 'wsock32', 'advapi32']
    runtime_library_dirs = []
    extra_objects = []
    # extra_objects = [r'c:\mysql\lib\opt\mysqlclient.lib']
elif sys.platform == "darwin6": 
    include_dirs=['/Users/tcchou/works/BerkeleyDB/include',
		'/Users/tcchou/works/libtabe/include']
    library_dirs=['/Users/tcchou/works/BerkeleyDB/lib',
		'/Users/tcchou/works/libtabe/lib']
    libraries = ["tabe", "db"]
    runtime_library_dirs = []
    extra_objects = []
elif os.name == "posix": # most Linux/UNIX platforms
    include_dirs=['/usr/local/db/BerkeleyDB/include','/usr/local/tabe/include']
    library_dirs=['/usr/local/db/BerkeleyDB/lib','/usr/local/tabe/lib']
    libraries = ["tabe", "db"]
    # On some platorms, this can be used to find the shared libraries
    # at runtime, if they are in a non-standard location. Doesn't
    # work for Linux gcc.
    ## runtime_library_dirs = library_dirs
    runtime_library_dirs = []
    # This can be used on Linux to force use of static mysqlclient lib
    ## extra_objects = ['/usr/lib/mysql/libmysqlclient.a']
    extra_objects = ['/usr/local/db/BerkeleyDB/lib/libdb.a']
else:
    raise "UnknownPlatform", "sys.platform=%s, os.name=%s" % \
          (sys.platform, os.name)
    
long_description = \
"""
CSplitter
Chinese Splitter
"""

tabelib = Extension(    name='CSplitter.tabelib',
                        sources=['src/tabelibmodule.c'],
                        include_dirs=include_dirs,
                        library_dirs=library_dirs,
		                runtime_library_dirs=runtime_library_dirs,
                        libraries=libraries,
		                extra_objects=extra_objects )

setup (# Distribution meta-data
        name = "CSplitter",
        version = "0.0.4",
        description = "Chinese Splitter",
	    long_description= long_description,
        author = "T.C. Chou",
        author_email = "tcchou@eibsoft.com",
	licence = "BSD",
        url = "http://www.zope.org",

        # Description of the modules and packages in the distribution

        py_modules = [  "CSplitter.CSplitter"
                     ],

        ext_modules = [ tabelib,
                      ],
)
